@@ -1,6 +1,7 @@
 from PIL import Image
 from PIL import ImageDraw
 from PIL import ImageFont
+from StringIO import StringIO
 
 # Change these values to match your needs
 cert_file = '/home/apyb/certificado2009.png'
@@ -19,7 +20,10 @@ def generate(name, role):
     pos = 3500 ,2230
     draw.text(pos, role, font=font)
 
-    return img.tostring()
+    output = StringIO()
+    img.save(output, format='PNG')
+
+    return output.getvalue()
 
 if __name__ == '__main__':
     print generate('Dorneles Tremea', 'participante')
