@@ -49,10 +49,10 @@ schema = Schema((
             label_msgid='PyConBrasil_label_trilha',
             description_msgid='PyConBrasil_help_trilha',
             i18n_domain='PyConBrasil',
+            visible=0,
         ),
-        enforceVocabulary=True,
         vocabulary='getTrilhas',
-        required=True
+        required=False
     ),
 
     StringField(
@@ -116,7 +116,6 @@ schema = Schema((
 
     StringField(
         name='tempo',
-        index="FieldIndex:brains",
         widget=SelectionWidget
         (
             description="Duração estimada da apresentação de seu trabalho.",
@@ -133,8 +132,7 @@ schema = Schema((
 
     StringField(
         name='nome',
-        index=""":schema
-        FieldIndex:brains""",
+        index="FieldIndex:brains",
         widget=StringWidget(
             description="Informe o seu nome completo.",
             label='Nome',
@@ -152,7 +150,7 @@ schema = Schema((
             rows="5",
             cols="40",
             label="Curriculum do palestrante",
-            description="Apresente, de maneira resumida ,o seu curriculum",
+            description="Apresente, de maneira resumida, o seu curriculum.",
             label_msgid='PyConBrasil_label_curriculum',
             description_msgid='PyConBrasil_help_curriculum',
             i18n_domain='PyConBrasil',
@@ -165,7 +163,7 @@ schema = Schema((
         name='image',
         widget=ImageWidget(
             label="Foto do Palestrante",
-            description="Forneça uma foto sua nas proporções 3x4",
+            description="Forneça uma foto sua na proporção 3x4.",
             label_msgid='PyConBrasil_label_image',
             description_msgid='PyConBrasil_help_image',
             i18n_domain='PyConBrasil',
@@ -201,7 +199,7 @@ schema = Schema((
             i18n_domain='PyConBrasil',
         ),
         required=1,
-        read_permission="Modify portal contents",
+        read_permission="Modify portal content",
         validators=('isEmail',)
     ),
 
@@ -218,7 +216,7 @@ schema = Schema((
             i18n_domain='PyConBrasil',
         ),
         required=True,
-        read_permission="Modify portal contents"
+        read_permission="Modify portal content"
     ),
 
     StringField(
@@ -263,7 +261,7 @@ schema = Schema((
             description_msgid='PyConBrasil_help_endereco',
             i18n_domain='PyConBrasil',
         ),
-        read_permission="Modify portal contents"
+        read_permission="Modify portal content"
     ),
 
     StringField(
@@ -276,7 +274,7 @@ schema = Schema((
             description_msgid='PyConBrasil_help_instituicao',
             i18n_domain='PyConBrasil',
         ),
-        read_permission="Modify portal contents"
+        read_permission="Modify portal content"
     ),
 
     TextField(
@@ -289,16 +287,16 @@ schema = Schema((
             description_msgid='PyConBrasil_help_observacoes',
             i18n_domain='PyConBrasil',
         ),
-        read_permission="Modify portal contents"
+        read_permission="Modify portal content"
     ),
 
     BooleanField(
         name='usoImagem',
-        default="False",
+        default="True",
         index="FieldIndex:brains",
         widget=BooleanWidget(
             label="Uso de imagem",
-            description="Você cede o uso de sua palestra para a Fundação Python Brasil disponibilizar os vídeos e materiais do evento para a comunidade",
+            description="Você cede o uso de sua palestra para a Associação Python Brasil disponibilizar os vídeos e materiais do evento para a comunidade?",
             label_msgid='PyConBrasil_label_usoImagem',
             description_msgid='PyConBrasil_help_usoImagem',
             i18n_domain='PyConBrasil',
